@@ -46,6 +46,14 @@ class PasswordManager:
         )
 
 
+class DummyPasswordManager(PasswordManager):
+    def _get(self, key: str) -> Optional[str]:
+        return ""
+
+    def _set(self, key: str, value: str) -> None:
+        return
+
+
 PASSWORD_MANAGER_AVAILABLE = None
 
 
